@@ -1,4 +1,4 @@
-"""A simple setup script to create an executable using PyQt5 QtWebEngineWidgets.
+"""Creates an executable using PyQt5 QtWebEngineWidgets.
 This also demonstrates how to use excludes to get minimal package size.
 
 Run the build process by running the command 'python setup.py build'
@@ -14,15 +14,7 @@ from cx_Freeze import Executable, setup
 options = {
     "build_exe": {
         # exclude packages that are not really needed
-        "excludes": [
-            "tkinter",
-            "unittest",
-            "email",
-            "http",
-            "xml",
-            "pydoc",
-        ],
-        "zip_include_packages": ["PyQt5"],
+        "excludes": ["tkinter", "unittest", "email", "http", "xml", "pydoc"]
     },
     "bdist_mac": {"bundle_name": "PyQt5 Webengine Test"},
 }
@@ -35,7 +27,7 @@ executables = [
 
 setup(
     name="simplebrowser",
-    version="0.1",
+    version="7.2",
     description="cx_Freeze and PyQt5 Webengine sample",
     options=options,
     executables=executables,
