@@ -10,6 +10,7 @@ from cx_Freeze._compat import (
     IS_LINUX,
     IS_MACOS,
     IS_MINGW,
+    IS_UCRT,
     IS_WINDOWS,
 )
 
@@ -46,9 +47,9 @@ pyproject.toml
     reason="av (pyAV) is too slow in conda-forge (Linux and OSX_ARM64)",
 )
 @pytest.mark.xfail(
-    IS_MINGW,
+    IS_MINGW and not IS_UCRT,
     raises=ModuleNotFoundError,
-    reason="av (pyAV) not supported in mingw",
+    reason="av (pyAV) supported only in mingw linked to ucrt",
     strict=True,
 )
 @pytest.mark.xfail(
