@@ -22,7 +22,8 @@ from .datatest import (
     MAYBE_TEST,
     MAYBE_TEST_NEW,
     NAMESPACE_TEST,
-    NESTED_NAMESPACE_TEST,
+    NAMESPACE_TEST_1,
+    NAMESPACE_TEST_2,
     PACKAGE_TEST,
     RELATIVE_IMPORT_TEST,
     RELATIVE_IMPORT_TEST_2,
@@ -88,7 +89,8 @@ def _do_test(
         MAYBE_TEST,
         MAYBE_TEST_NEW,
         NAMESPACE_TEST,
-        NESTED_NAMESPACE_TEST,
+        NAMESPACE_TEST_1,
+        NAMESPACE_TEST_2,
         PACKAGE_TEST,
         RELATIVE_IMPORT_TEST,
         RELATIVE_IMPORT_TEST_2,
@@ -106,7 +108,8 @@ def _do_test(
         "maybe_test",
         "maybe_test_new",
         "namespace_test",
-        "nested_namespace_test",
+        "namespace_test_1",
+        "namespace_test_2",
         "package_test",
         "relative_import_test",
         "relative_import_test_2",
